==> react_image_annotate_ns_workflow-4.0.1.tgz: package/OCR/FormOCR.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";

/* eslint-disable no-loop-func */

/* eslint-disable no-unused-expressions */
import { Typography } from "@mui/material";
import React from "react";
import CreatableSelect from "react-select/creatable";
import NormalInput from "../Components/AnnoatationNormalInput";
import AnnotationInput from "../Components/AnnotationInput";
import LocalStorage from "../Components/LocalStorage";
import { errorSpan, fielderror, isNonMandatoryEditable, ShowCount, trimRule } from "../Components/ValidationCheck";
var Getrules = LocalStorage.get_task_rules() || {};
var editable_type = ["textArea", "dropdown", "multiSelectDropdown", "dependentDropdown", "input", "date", "checkbox", "radio", "classification", "tags", "text_annotation"];

function FormOCR(_ref) {
  var _dependent_rule_all_d, _dependent_rule_all_d2, _dependent_rule_all_d3, _ref7, _ref7$find, _getDropdown_data$get, _getDropdown_data$get2, _LocalStorage$get_dro, _LocalStorage$get_dro2;

  var index = _ref.index,
      formData = _ref.formData,
      setFormData = _ref.setFormData,
      item = _ref.item,
      editable_arr = _ref.editable_arr,
      customized_column_arr = _ref.customized_column_arr,
      column_key = _ref.column_key,
      setCustomize = _ref.setCustomize;

  var _ref2 = item || {},
      invalid = _ref2.invalid,
      description_labelling = _ref2.description_labelling,
      image_urls_labelling = _ref2.image_urls_labelling,
      title = _ref2.title,
      default_type = _ref2.default_type,
      display_label = _ref2.display_label,
      content = _ref2.content,
      input_type = _ref2.input_type,
      value = _ref2.value,
      other_value = _ref2.other_value,
      mandatory = _ref2.mandatory,
      history_hide = _ref2.history_hide,
      editable_data = _ref2.editable_data;

  var labelStyle = {
    width: "90%",
    overflow: "hidden",
    wordBreak: "break-all",
    display: "inline-block"
  };

  var _ref3 = Getrules || {},
      rules = _ref3.rules,
      editable_fields = _ref3.editable_fields,
      save_mandatory_fields = _ref3.save_mandatory_fields,
      find_and_replace = _ref3.find_and_replace,
      hide_physical_link = _ref3.hide_physical_link,
      dropdown_data = _ref3.dropdown_data,
      symbol_find_replace = _ref3.symbol_find_replace,
      dependent_rule_all_data = _ref3.dependent_rule_all_data;

  var rule_arr = rules === null || rules === void 0 ? void 0 : rules[title];

  var onActionFieldError = function onActionFieldError(title, border) {
    return fielderror(rule_arr, content, editable_arr, "form", false, title, border);
  };

  var fieldValidationMessage = function fieldValidationMessage(border) {
    var _ref4 = onActionFieldError() || {},
        keys = _ref4.keys,
        messageShow = _ref4.messageShow;

    var errorMess = border ? messageShow === null || messageShow === void 0 ? void 0 : messageShow.length : errorSpan(messageShow);
    return keys !== "roundoff" ? keys !== "concat" ? onActionFieldError() : errorMess : errorMess;
  };

  var handleOnChangeFields = function handleOnChangeFields(value) {
    var _onActionFieldError = onActionFieldError(),
        keys = _onActionFieldError.keys,
        values = _onActionFieldError.values;

    var data = _toConsumableArray(editable_arr);

    if (keys === "concat") {
      data[index].content = values;
    } else {
      data[index].content = value;
    }

    setFormData(data);
  };

  var handleRulesApplyOnFoucsBlur = function handleRulesApplyOnFoucsBlur() {
    var _ref5 = onActionFieldError() || {},
        keys = _ref5.keys,
        values = _ref5.values;

    keys === "roundoff" ? handleOnChangeFields(values, false) : null;
    keys === "concat" ? handleOnChangeFields(values, false) : null;
    var find_replace_arr = (find_and_replace === null || find_and_replace === void 0 ? void 0 : find_and_replace[title]) || [];
    var string = values || content;

    if (keys === "concat") {
      string = values;
    }

    try {
      if (string) {
        for (var i = 0; i < (find_replace_arr === null || find_replace_arr === void 0 ? void 0 : find_replace_arr.length); i++) {
          var _string;

          string = (_string = string) === null || _string === void 0 ? void 0 : _string.replaceAll(find_replace_arr[i].search, find_replace_arr[i].replace);
        }

        var symbol_find_replace_rule = (symbol_find_replace === null || symbol_find_replace === void 0 ? void 0 : symbol_find_replace[title]) || {};

        var _ref6 = symbol_find_replace_rule || {},
            find_replace = _ref6.find_replace,
            symbol = _ref6.symbol;

        var symbol_rule_string = "";

        if (find_replace !== null && find_replace !== void 0 && find_replace.length && symbol_rule_string) {
          string = symbol_rule_string;
        }

        string = trimRule({
          rules_arr: rule_arr,
          content: string
        });
        handleOnChangeFields(string);
      }
    } catch (err) {
      console.log("handle_symbol_find_replace break", err);
    }
  };

  var getDependentFields = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d = dependent_rule_all_data[0]) === null || _dependent_rule_all_d === void 0 ? void 0 : (_dependent_rule_all_d2 = _dependent_rule_all_d.dependent_rule) === null || _dependent_rule_all_d2 === void 0 ? void 0 : _dependent_rule_all_d2[title];
  var getDropdown_data = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d3 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d3 === void 0 ? void 0 : _dependent_rule_all_d3.dependent_data;
  var getFieldContent = ((_ref7 = [].concat(_toConsumableArray(editable_arr), _toConsumableArray(customized_column_arr))) === null || _ref7 === void 0 ? void 0 : (_ref7$find = _ref7.find(function (item) {
    return item.title === getDependentFields;
  })) === null || _ref7$find === void 0 ? void 0 : _ref7$find.content) || "";

  var handledependentDropdown = function handledependentDropdown(event, detect, isDependent, title) {
    var update_Dependentvalue = function update_Dependentvalue(arr) {
      var editable = _toConsumableArray(editable_arr);

      var customize = _toConsumableArray(customized_column_arr);

      var editable_key = "";
      var customized_key = "";

      if (column_key === "editable_column") {
        editable_key = "editable";
        customized_key = "customized_column";
      } else if (column_key === "customized_column") {
        editable_key = "customized_column";
        customized_key = "editable";
      }

      editable.map(function (item, editable) {
        if (arr.includes(String(item.title))) {
          var data = _toConsumableArray(editable_arr);

          data[editable].content = "";
          setFormData(data);
        }
      });
      customize === null || customize === void 0 ? void 0 : customize.map(function (item, customizeIndex) {
        if (arr.includes(String(item.title))) {
          var data = _toConsumableArray(customized_column_arr);

          data[customizeIndex].content = "";
          setCustomize(data);
        }
      });
    };

    if (!detect && isDependent) {
      var _dependent_rule_all_d4;

      var dependentKeys = Object.keys((dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d4 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d4 === void 0 ? void 0 : _dependent_rule_all_d4.dependent_rule) || {});
      update_Dependentvalue(dependentKeys);
    } else if (isDependent) {
      (function () {
        var _dependent_rule_all_d5;

        var d = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d5 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d5 === void 0 ? void 0 : _dependent_rule_all_d5.dependent_rule;
        var d1 = [];
        var current = title;
        var nextCheck = false;

        do {
          nextCheck = false;
          Object.keys(d).map(function (key) {
            if (d[key] === current) {
              nextCheck = true;
              d1.push(key);
              current = key;
            }
          });
        } while (nextCheck);

        update_Dependentvalue(d1);
      })();
    }

    handleOnChangeFields(event, false, event);

    if (!detect && isDependent) {
      var _dependent_rule_all_d6;

      var _dependentKeys = Object.keys((dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d6 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d6 === void 0 ? void 0 : _dependent_rule_all_d6.dependent_rule) || {});

      update_Dependentvalue(_dependentKeys);
    }
  };

  var _ref8 = isNonMandatoryEditable({
    rules_arr: rule_arr,
    editable_arr: [].concat(_toConsumableArray(editable_arr), [customized_column_arr])
  }) || {},
      readOnly = _ref8.readOnly,
      valueExist = _ref8.valueExist;

  var editable = (editable_fields === null || editable_fields === void 0 ? void 0 : editable_fields.includes(title)) && (editable_type.includes(input_type) ? true : false);
  return input_type === "label" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("p", {
    className: "font-MontSemiBold task_formlabel"
  }, display_label), /*#__PURE__*/React.createElement(Typography, null, content)) : input_type === "textArea" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(AnnotationInput, {
    labelClass: "task_formlabel",
    isRequired: mandatory === "mandatory",
    rows: 3,
    title: display_label,
    id: display_label,
    value: content,
    fullWidth: true,
    onChange: function onChange(e) {
      handleOnChangeFields(e.target.value);
    },
    focused: true,
    onblur: function onblur() {
      return handleRulesApplyOnFoucsBlur();
    },
    readOnly: valueExist ? readOnly : false
  }), ShowCount({
    rules_arr: rules === null || rules === void 0 ? void 0 : rules[display_label]
  }) && /*#__PURE__*/React.createElement("span", {
    style: {
      fontSize: "0.7rem"
    },
    className: "text-green-600 flex justify-start"
  }, String(content).length), fieldValidationMessage()) : input_type === "input" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(NormalInput, {
    onFocus: function onFocus() {
      return handleRulesApplyOnFoucsBlur();
    },
    labelClass: "task_formlabel",
    title: display_label,
    value: content,
    onChange: function onChange(e) {
      handleOnChangeFields(e.target.value);
    },
    isRequired: (save_mandatory_fields === null || save_mandatory_fields === void 0 ? void 0 : save_mandatory_fields.includes(title)) || mandatory === "mandatory",
    isAstrick: save_mandatory_fields === null || save_mandatory_fields === void 0 ? void 0 : save_mandatory_fields.includes(title),
    onblur: function onblur() {
      handleRulesApplyOnFoucsBlur();
    },
    count: false,
    isTooltip: true,
    readOnly: valueExist ? readOnly : false
  }), ShowCount({
    rules_arr: rules === null || rules === void 0 ? void 0 : rules[display_label]
  }) && /*#__PURE__*/React.createElement("span", {
    style: {
      fontSize: "0.7rem"
    },
    className: "text-green-600 flex justify-start"
  }, String(content).length), fieldValidationMessage()) : input_type === "dependentDropdown" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle)
  }, display_label), /*#__PURE__*/React.createElement(CreatableSelect, {
    isSearchable: true,
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(e) {
      handledependentDropdown(e.value, getDependentFields, true, title);
    },
    placeholder: display_label,
    value: content && {
      value: content,
      label: content
    },
    options: getDependentFields ? (_getDropdown_data$get = getDropdown_data[getDependentFields]) === null || _getDropdown_data$get === void 0 ? void 0 : (_getDropdown_data$get2 = _getDropdown_data$get[getFieldContent]) === null || _getDropdown_data$get2 === void 0 ? void 0 : _getDropdown_data$get2.map(function (c) {
      return {
        value: c,
        label: c
      };
    }) : Object.keys((getDropdown_data === null || getDropdown_data === void 0 ? void 0 : getDropdown_data[title]) || {}).map(function (c) {
      return {
        value: c,
        label: c
      };
    })
  })) : input_type === "dropdown" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle)
  }, display_label), /*#__PURE__*/React.createElement(CreatableSelect, {
    isSearchable: true,
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(e) {
      handleOnChangeFields(e.value, getDependentFields, true, title);
    },
    placeholder: display_label,
    value: content && {
      value: content,
      label: content
    },
    options: (_LocalStorage$get_dro = LocalStorage.get_dropdown()) === null || _LocalStorage$get_dro === void 0 ? void 0 : (_LocalStorage$get_dro2 = _LocalStorage$get_dro[title]) === null || _LocalStorage$get_dro2 === void 0 ? void 0 : _LocalStorage$get_dro2.map(function (c) {
      return {
        label: c.label,
        value: c.value
      };
    })
  })) : null;
}

export default FormOCR;

==> react_image_annotate_ns_workflow-4.0.4.tgz: package/OCR/FormOCR.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";

/* eslint-disable no-loop-func */

/* eslint-disable no-unused-expressions */
import { Typography } from "@mui/material";
import React from "react";
import CreatableSelect from "react-select/creatable";
import NormalInput from "../Components/AnnoatationNormalInput";
import AnnotationInput from "../Components/AnnotationInput";
import LocalStorage from "../Components/LocalStorage";
import { errorSpan, fielderror, isNonMandatoryEditable, ShowCount, trimRule } from "../Components/ValidationCheck";
var Getrules = LocalStorage.get_task_rules() || {};
var editable_type = ["textArea", "dropdown", "multiSelectDropdown", "dependentDropdown", "input", "date", "checkbox", "radio", "classification", "tags", "text_annotation"];

function FormOCR(_ref) {
  var _dependent_rule_all_d, _dependent_rule_all_d2, _dependent_rule_all_d3, _ref7, _ref7$find, _getDropdown_data$get, _getDropdown_data$get2, _LocalStorage$get_dro, _LocalStorage$get_dro2;

  var index = _ref.index,
      formData = _ref.formData,
      setFormData = _ref.setFormData,
      item = _ref.item,
      editable_arr = _ref.editable_arr,
      customized_column_arr = _ref.customized_column_arr,
      column_key = _ref.column_key,
      setCustomize = _ref.setCustomize,
      _ref$access_block = _ref.access_block,
      access_block = _ref$access_block === void 0 ? [] : _ref$access_block;

  var _ref2 = item || {},
      invalid = _ref2.invalid,
      description_labelling = _ref2.description_labelling,
      image_urls_labelling = _ref2.image_urls_labelling,
      title = _ref2.title,
      default_type = _ref2.default_type,
      display_label = _ref2.display_label,
      content = _ref2.content,
      input_type = _ref2.input_type,
      value = _ref2.value,
      other_value = _ref2.other_value,
      mandatory = _ref2.mandatory,
      history_hide = _ref2.history_hide,
      editable_data = _ref2.editable_data;

  var labelStyle = {
    width: "90%",
    overflow: "hidden",
    wordBreak: "break-all",
    display: "inline-block",
    textOverflow: "ellipsis",
    whiteSpace: "nowrap"
  };

  var _ref3 = Getrules || {},
      rules = _ref3.rules,
      editable_fields = _ref3.editable_fields,
      save_mandatory_fields = _ref3.save_mandatory_fields,
      find_and_replace = _ref3.find_and_replace,
      hide_physical_link = _ref3.hide_physical_link,
      dropdown_data = _ref3.dropdown_data,
      symbol_find_replace = _ref3.symbol_find_replace,
      dependent_rule_all_data = _ref3.dependent_rule_all_data;

  var rule_arr = rules === null || rules === void 0 ? void 0 : rules[title];

  var onActionFieldError = function onActionFieldError(title, border) {
    return fielderror(rule_arr, content, editable_arr, "form", false, title, border);
  };

  var fieldValidationMessage = function fieldValidationMessage(border) {
    var _ref4 = onActionFieldError() || {},
        keys = _ref4.keys,
        messageShow = _ref4.messageShow;

    var errorMess = border ? messageShow === null || messageShow === void 0 ? void 0 : messageShow.length : errorSpan(messageShow);
    return keys !== "roundoff" ? keys !== "concat" ? onActionFieldError() : errorMess : errorMess;
  };

  var handleOnChangeFields = function handleOnChangeFields(value) {
    var _onActionFieldError = onActionFieldError(),
        keys = _onActionFieldError.keys,
        values = _onActionFieldError.values;

    var data = _toConsumableArray(editable_arr);

    if (keys === "concat") {
      data[index].content = values;
    } else {
      data[index].content = value;
    }

    setFormData(data);
  };

  var handleRulesApplyOnFoucsBlur = function handleRulesApplyOnFoucsBlur() {
    var _ref5 = onActionFieldError() || {},
        keys = _ref5.keys,
        values = _ref5.values;

    keys === "roundoff" ? handleOnChangeFields(values, false) : null;
    keys === "concat" ? handleOnChangeFields(values, false) : null;
    var find_replace_arr = (find_and_replace === null || find_and_replace === void 0 ? void 0 : find_and_replace[title]) || [];
    var string = values || content;

    if (keys === "concat") {
      string = values;
    }

    try {
      if (string) {
        for (var i = 0; i < (find_replace_arr === null || find_replace_arr === void 0 ? void 0 : find_replace_arr.length); i++) {
          var _string;

          string = (_string = string) === null || _string === void 0 ? void 0 : _string.replaceAll(find_replace_arr[i].search, find_replace_arr[i].replace);
        }

        var symbol_find_replace_rule = (symbol_find_replace === null || symbol_find_replace === void 0 ? void 0 : symbol_find_replace[title]) || {};

        var _ref6 = symbol_find_replace_rule || {},
            find_replace = _ref6.find_replace,
            symbol = _ref6.symbol;

        var symbol_rule_string = "";

        if (find_replace !== null && find_replace !== void 0 && find_replace.length && symbol_rule_string) {
          string = symbol_rule_string;
        }

        string = trimRule({
          rules_arr: rule_arr,
          content: string
        });
        handleOnChangeFields(string);
      }
    } catch (err) {
      console.log("handle_symbol_find_replace break", err);
    }
  };

  var getDependentFields = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d = dependent_rule_all_data[0]) === null || _dependent_rule_all_d === void 0 ? void 0 : (_dependent_rule_all_d2 = _dependent_rule_all_d.dependent_rule) === null || _dependent_rule_all_d2 === void 0 ? void 0 : _dependent_rule_all_d2[title];
  var getDropdown_data = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d3 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d3 === void 0 ? void 0 : _dependent_rule_all_d3.dependent_data;
  var getFieldContent = ((_ref7 = [].concat(_toConsumableArray(editable_arr), _toConsumableArray(customized_column_arr))) === null || _ref7 === void 0 ? void 0 : (_ref7$find = _ref7.find(function (item) {
    return item.title === getDependentFields;
  })) === null || _ref7$find === void 0 ? void 0 : _ref7$find.content) || "";

  var handledependentDropdown = function handledependentDropdown(event, detect, isDependent, title) {
    var update_Dependentvalue = function update_Dependentvalue(arr) {
      var editable = _toConsumableArray(editable_arr);

      var customize = _toConsumableArray(customized_column_arr);

      var editable_key = "";
      var customized_key = "";

      if (column_key === "editable_column") {
        editable_key = "editable";
        customized_key = "customized_column";
      } else if (column_key === "customized_column") {
        editable_key = "customized_column";
        customized_key = "editable";
      }

      editable.map(function (item, editable) {
        if (arr.includes(String(item.title))) {
          var data = _toConsumableArray(editable_arr);

          data[editable].content = "";
          setFormData(data);
        }
      });
      customize === null || customize === void 0 ? void 0 : customize.map(function (item, customizeIndex) {
        if (arr.includes(String(item.title))) {
          var data = _toConsumableArray(customized_column_arr);

          data[customizeIndex].content = "";
          setCustomize(data);
        }
      });
    };

    if (!detect && isDependent) {
      var _dependent_rule_all_d4;

      var dependentKeys = Object.keys((dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d4 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d4 === void 0 ? void 0 : _dependent_rule_all_d4.dependent_rule) || {});
      update_Dependentvalue(dependentKeys);
    } else if (isDependent) {
      (function () {
        var _dependent_rule_all_d5;

        var d = dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d5 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d5 === void 0 ? void 0 : _dependent_rule_all_d5.dependent_rule;
        var d1 = [];
        var current = title;
        var nextCheck = false;

        do {
          nextCheck = false;
          Object.keys(d).map(function (key) {
            if (d[key] === current) {
              nextCheck = true;
              d1.push(key);
              current = key;
            }
          });
        } while (nextCheck);

        update_Dependentvalue(d1);
      })();
    }

    handleOnChangeFields(event, false, event);

    if (!detect && isDependent) {
      var _dependent_rule_all_d6;

      var _dependentKeys = Object.keys((dependent_rule_all_data === null || dependent_rule_all_data === void 0 ? void 0 : (_dependent_rule_all_d6 = dependent_rule_all_data[0]) === null || _dependent_rule_all_d6 === void 0 ? void 0 : _dependent_rule_all_d6.dependent_rule) || {});

      update_Dependentvalue(_dependentKeys);
    }
  };

  var _ref8 = isNonMandatoryEditable({
    rules_arr: rule_arr,
    editable_arr: [].concat(_toConsumableArray(editable_arr), [customized_column_arr])
  }) || {},
      readOnly = _ref8.readOnly,
      valueExist = _ref8.valueExist;

  var editable = (editable_fields === null || editable_fields === void 0 ? void 0 : editable_fields.includes(title)) && (editable_type.includes(input_type) ? true : false);
  return access_block.includes(title) ? null : input_type === "label" ? /*#__PURE__*/React.createElement("div", {
    id: "image_ocr"
  }, /*#__PURE__*/React.createElement("span", {
    className: "font-MontSemiBold task_formlabel",
    style: {
      width: "80%",
      whiteSpace: "no",
      textOverflow: "ellipsis",
      overFlow: "hidden"
    }
  }, display_label), /*#__PURE__*/React.createElement(Typography, null, content)) : input_type === "textArea" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(AnnotationInput, {
    labelClass: "task_formlabel",
    isRequired: mandatory === "mandatory",
    rows: 3,
    title: display_label,
    id: display_label,
    value: content,
    fullWidth: true,
    onChange: function onChange(e) {
      handleOnChangeFields(e.target.value);
    },
    focused: true,
    onblur: function onblur() {
      return handleRulesApplyOnFoucsBlur();
    },
    readOnly: valueExist ? readOnly : false
  }), ShowCount({
    rules_arr: rules === null || rules === void 0 ? void 0 : rules[display_label]
  }) && /*#__PURE__*/React.createElement("span", {
    style: {
      fontSize: "0.7rem"
    },
    className: "text-green-600 flex justify-start"
  }, String(content).length), fieldValidationMessage()) : input_type === "input" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(NormalInput, {
    onFocus: function onFocus() {
      return handleRulesApplyOnFoucsBlur();
    },
    labelClass: "task_formlabel",
    title: display_label,
    value: content,
    onChange: function onChange(e) {
      handleOnChangeFields(e.target.value);
    },
    isRequired: (save_mandatory_fields === null || save_mandatory_fields === void 0 ? void 0 : save_mandatory_fields.includes(title)) || mandatory === "mandatory",
    isAstrick: save_mandatory_fields === null || save_mandatory_fields === void 0 ? void 0 : save_mandatory_fields.includes(title),
    onblur: function onblur() {
      handleRulesApplyOnFoucsBlur();
    },
    count: false,
    isTooltip: true,
    readOnly: valueExist ? readOnly : false
  }), ShowCount({
    rules_arr: rules === null || rules === void 0 ? void 0 : rules[display_label]
  }) && /*#__PURE__*/React.createElement("span", {
    style: {
      fontSize: "0.7rem"
    },
    className: "text-green-600 flex justify-start"
  }, String(content).length), fieldValidationMessage()) : input_type === "dependentDropdown" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle),
    title: display_label
  }, display_label), /*#__PURE__*/React.createElement(CreatableSelect, {
    isSearchable: true,
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(e) {
      handledependentDropdown(e.value, getDependentFields, true, title);
    },
    placeholder: display_label,
    value: content && {
      value: content,
      label: content
    },
    options: getDependentFields ? (_getDropdown_data$get = getDropdown_data[getDependentFields]) === null || _getDropdown_data$get === void 0 ? void 0 : (_getDropdown_data$get2 = _getDropdown_data$get[getFieldContent]) === null || _getDropdown_data$get2 === void 0 ? void 0 : _getDropdown_data$get2.map(function (c) {
      return {
        value: c,
        label: c
      };
    }) : Object.keys((getDropdown_data === null || getDropdown_data === void 0 ? void 0 : getDropdown_data[title]) || {}).map(function (c) {
      return {
        value: c,
        label: c
      };
    })
  })) : input_type === "dropdown" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "title_input_box task_formlabel",
    style: _objectSpread({}, labelStyle),
    title: title
  }, display_label), /*#__PURE__*/React.createElement(CreatableSelect, {
    isSearchable: true,
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(e) {
      handleOnChangeFields(e.value, getDependentFields, true, title);
    },
    placeholder: display_label,
    value: content && {
      value: content,
      label: content
    },
    options: (_LocalStorage$get_dro = LocalStorage.get_dropdown()) === null || _LocalStorage$get_dro === void 0 ? void 0 : (_LocalStorage$get_dro2 = _LocalStorage$get_dro[title]) === null || _LocalStorage$get_dro2 === void 0 ? void 0 : _LocalStorage$get_dro2.map(function (c) {
      return {
        label: c.label,
        value: c.value
      };
    })
  })) : null;
}

export default FormOCR;
